#
# spec file for package gstreamer
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           gstreamer
%define _name   gstreamer
%define build_doc 0
Version:        1.4.5
Release:        58.2
%define gst_branch 1.0
Summary:        Streaming-Media Framework Runtime
License:        LGPL-2.1+
Group:          Productivity/Multimedia/Other
Url:            http://gstreamer.freedesktop.org/
Source0:        http://gstreamer.freedesktop.org/src/gstreamer/%{_name}-%{version}.tar.xz
Source1:        gstreamer.macros
Source2:        gstreamer.prov
Source99:       baselibs.conf
# PATCH-FIX-OPENSUSE gstreamer-no-gtk-doc-for-reals.patch maw@novell.com -- to build without gtk-doc, like totally for reals
Patch0:         gstreamer-no-gtk-doc-for-reals.patch
# PATCH-FEATURE-UPSTREAM gstreamer-rpm-prov.patch bgo#588783 dimstar@opensuse.org -- Add --rpm parameter to allow creation of rpm provides, patch from fedora
Patch1:         gstreamer-rpm-prov.patch
# http://cgit.freedesktop.org/gstreamer/gstreamer/commit/?id=da7847d1adde
# PATCH-FIX-UPSTREAM gstreamer-message-delivery.patch dap.darkness@gmail.com -- to fix async message delivery
Patch2:         gstreamer-message-delivery.patch
BuildRequires:  bison
BuildRequires:  check-devel
BuildRequires:  fdupes
BuildRequires:  flex
BuildRequires:  glib2-devel >= 2.32.0
BuildRequires:  gnome-patch-translation
BuildRequires:  libtool
BuildRequires:  libxml2-devel
BuildRequires:  translation-update-upstream
%ifarch %ix86 ppc x86_64
BuildRequires:  valgrind-devel
%endif
%if %suse_version >= 1120
BuildRequires:  gobject-introspection-devel >= 1.31.1
%endif
%if %build_doc
BuildRequires:  docbook-toys
BuildRequires:  docbook-utils
BuildRequires:  gtk-doc >= 1.12
BuildRequires:  python
BuildRequires:  texlive-latex
BuildRequires:  texlive-latex-doc
BuildRequires:  transfig
# Ensure that the documentation corresponds with the installed version:
Requires:       libgstreamer-1_0-0 = %{version}
# Generic name, never used in SuSE:
Provides:       gstreamer-doc = %{version}
%else
# Core modules may depend on new enough libraries:
Requires:       libgstreamer-1_0-0 >= %{version}
Recommends:     %{name}-lang = %{version}
%endif
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
GStreamer is a streaming-media framework, based on graphs of filters
which operate on media data. Applications using this library can do
anything from real-time sound processing to playing videos, and just
about anything else media-related.  Its plug-in-based architecture
means that new data types or processing capabilities can be added by
installing new plug-ins.

%if !%build_doc

%package -n libgstreamer-1_0-0
Summary:        Streaming-Media Framework Runtime
Group:          System/Libraries
# We want to have core modules installed:
Requires:       %{name}

%description -n libgstreamer-1_0-0
GStreamer is a streaming-media framework, based on graphs of filters
which operate on media data. Applications using this library can do
anything from real-time sound processing to playing videos, and just
about anything else media-related.  Its plug-in-based architecture
means that new data types or processing capabilities can be added by
installing new plug-ins.

%if %suse_version >= 1120
%package -n typelib-1_0-Gst-1_0
Summary:        Streaming-Media Framework Runtime -- Introspection bindings
Group:          System/Libraries

%description -n typelib-1_0-Gst-1_0
GStreamer is a streaming-media framework, based on graphs of filters
which operate on media data. Applications using this library can do
anything from real-time sound processing to playing videos, and just
about anything else media-related.  Its plug-in-based architecture
means that new data types or processing capabilities can be added by
installing new plug-ins.

This package provides the GObject Introspection bindings for GStreamer.
%endif

%package utils
Summary:        Streaming-Media Framework Runtime
Group:          Productivity/Multimedia/Other
# Generic name, never used in SuSE:
Provides:       gstreamer:%{_bindir}/gst-launch-%{gst_branch} = %{version}
# Symbol for unversioned wrappers:
Provides:       gstreamer-utils_versioned = %{version}

%description utils
GStreamer is a streaming-media framework, based on graphs of filters
which operate on media data. Applications using this library can do
anything from real-time sound processing to playing videos, and just
about anything else media-related.  Its plug-in-based architecture
means that new data types or processing capabilities can be added by
installing new plug-ins.

%package devel
Summary:        Include Files and Libraries mandatory for Development
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}
# gstreamer-utils is required for the gstreamer-provides rpm magic.
Requires:       gstreamer-utils = %{version}
Requires:       libgstreamer-1_0-0 = %{version}
%if %suse_version >= 1120
Requires:       typelib-1_0-Gst-1_0 = %{version}
%endif

%description devel
This package contains all necessary include files and libraries needed
to develop applications that require these.

%endif
%lang_package

%prep
%setup -q -n gstreamer-%{version}
translation-update-upstream po gstreamer-%{gst_branch}
gnome-patch-translation-prepare po gstreamer-%{gst_branch}
%if ! %build_doc
%patch0 -p1
%endif
%patch1 -p1
%patch2 -p1
gnome-patch-translation-update po gstreamer-%{gst_branch}

%build
# FIXME: GTKDOC_CFLAGS, GST_OBJ_CFLAGS:
# Silently ignored compilation of uninstalled gtk-doc scanners without RPM_OPT_FLAGS.
export V=1
%if %suse_version >= 1110
NOCONFIGURE=1 ./autogen.sh
%endif
export CFLAGS="%{optflags} -fno-strict-aliasing"
%configure\
%if %build_doc
	--enable-gtk-doc\
	--enable-docbook\
%endif
%if %suse_version >= 1120
        --enable-introspection\
%endif
	--disable-static
make %{?_smp_mflags}

%install
%makeinstall
mkdir -p %{buildroot}%{_datadir}/gstreamer-%{gst_branch}/presets
mkdir -p %{buildroot}%{_docdir}/%{name}
%if %build_doc
mv %{buildroot}%{_datadir}/doc/gstreamer-*/* %{buildroot}%{_docdir}/%{name}
rmdir %{buildroot}%{_datadir}/doc/gstreamer-*
%else
# TODO is empty
cp AUTHORS COPYING ChangeLog NEWS README RELEASE %{buildroot}%{_docdir}/%{name}
%find_lang %{name}-%{gst_branch}
rm %{buildroot}%{_libdir}/gstreamer-*/*.*a
%endif
%if %build_doc
rm -rf %{buildroot}%{_bindir}/*
rm -rf %{buildroot}%{_libdir}
rm -rf %{buildroot}%{_datadir}/aclocal
rm -rf %{buildroot}%{_includedir}/*
rm -rf %{buildroot}%{_datadir}/locale
rm -rf %{buildroot}%{_mandir}
rm -rf %{buildroot}%{_datadir}/gir-1.0/
rm -rf %{buildroot}%{_datadir}/gstreamer-%{gst_branch}
rm -rf %{buildroot}%{_libexecdir}/gstreamer-%{gst_branch}/gst-plugin-scanner
%else
rm -rf %{buildroot}%{_datadir}/gtk-doc
rm -rf %{buildroot}%{_docdir}/%{name}/manual
rm -rf %{buildroot}%{_docdir}/%{name}/pwg
mkdir -p %{buildroot}%{_datadir}/gstreamer-%{gst_branch}/presets
# Install the rpm macros
%if 0%?suse_version >= 1210
%__install -m644 -D %{S:1} %{buildroot}%{_libexecdir}/rpm/fileattrs/gstreamer.attr
%else
%__install -m644 -D %{S:1} %{buildroot}%{_sysconfdir}/rpm/macros.gstreamer
%endif
%__install -m755 -D %{S:2} %{buildroot}%{_libexecdir}/rpm/gstreamer-provides
%endif
%fdupes %{buildroot}

%clean
rm -rf %{buildroot}
%if ! %build_doc

%post -n libgstreamer-1_0-0 -p /sbin/ldconfig

%postun -n libgstreamer-1_0-0 -p /sbin/ldconfig
%endif
%if %build_doc

%files
%defattr(-,root,root)
%doc %dir %{_docdir}/%{name}
%{_datadir}/gtk-doc/html/*
%doc %{_docdir}/%{name}/manual
%doc %{_docdir}/%{name}/pwg
%doc %{_docdir}/%{name}/faq
%else

%files
%defattr(-, root, root)
%dir %{_datadir}/gstreamer-%{gst_branch}
%dir %{_datadir}/gstreamer-%{gst_branch}/presets
%doc %dir %{_docdir}/%{name}
%doc %{_docdir}/%{name}/AUTHORS
%doc %{_docdir}/%{name}/COPYING
%doc %{_docdir}/%{name}/ChangeLog
%doc %{_docdir}/%{name}/NEWS
%doc %{_docdir}/%{name}/README
%doc %{_docdir}/%{name}/RELEASE
%dir %{_libdir}/gstreamer-%{gst_branch}
%{_libdir}/gstreamer-%{gst_branch}/*.so
%dir %{_libexecdir}/gstreamer-%{gst_branch}
%{_libexecdir}/gstreamer-%{gst_branch}/gst-plugin-scanner

%files lang -f %{name}-%{gst_branch}.lang

%files -n libgstreamer-1_0-0
%defattr(-, root, root)
%{_libdir}/*.so.*

%if %suse_version >= 1120
%files -n typelib-1_0-Gst-1_0
%defattr(-, root, root)
%{_libdir}/girepository-1.0/Gst-1.0.typelib
%{_libdir}/girepository-1.0/GstBase-1.0.typelib
%{_libdir}/girepository-1.0/GstCheck-1.0.typelib
%{_libdir}/girepository-1.0/GstController-1.0.typelib
%{_libdir}/girepository-1.0/GstNet-1.0.typelib
%endif

%files utils
%defattr(-, root, root)
%{_bindir}/*-%{gst_branch}
%doc %{_mandir}/man?/*-%{gst_branch}.*

%files devel
%defattr(-, root, root)
%{_datadir}/aclocal/*.m4
%{_includedir}/*
%{_libdir}/*.so
%{_libdir}/*.*a
%{_libdir}/pkgconfig/*.pc
%{_libexecdir}/rpm/gstreamer-provides
%if 0%?suse_version >= 1210
%{_libexecdir}/rpm/fileattrs/gstreamer.attr
%else
%{_sysconfdir}/rpm/macros.gstreamer
%endif
%if %suse_version >= 1120
%{_datadir}/gir-1.0/*.gir
%endif
%endif

%changelog
* Sun Mar  1 2015 dap.darkness@gmail.com
- Added gstreamer-message-delivery.patch
  to fix async message delivery, see more at
  http://cgit.freedesktop.org/gstreamer/gstreamer/commit/?id=da7847
* Fri Dec 26 2014 zaitor@opensuse.org
- Update to version 1.4.5:
  + Bugs fixed: bgo#736969, bgo#738092, bgo#740001.
  + Updated translations.
* Mon Nov 17 2014 zaitor@opensuse.org
- Revert previous bashish "ﬁxes", but specify in pre_checkin.sh
  and gstreamer.prov scripts that interpeter is #!/bin/bash.
* Mon Nov 17 2014 Led <ledest@gmail.com>
- fix bashism in pre_checkin.sh script
* Mon Nov 17 2014 Led <ledest@gmail.com>
- fix bashisms in gstreamer.prov script
* Fri Nov 14 2014 zaitor@opensuse.org
- Update to version 1.4.4:
  + Bugs fixed: bgo#737498, bgo#737794, bgo#737999, bgo#738198.
  + Updated translations.
* Wed Sep 24 2014 dimstar@opensuse.org
- Update to version 1.4.3:
  + Bugs fixed: bgo#709868, bgo#736969, bgo#737102, bgo#737133.
  + Updated translations.
* Sun Sep 21 2014 dimstar@opensuse.org
- Update to version 1.4.2:
  + Bugs fixed: bgo#735574, bgo#734412, bgo#735975, bgo#729811,
    bgo#736455, bgo#736424, bgo#736680, bgo#736295, bgo#736736,
    bgo#736739, bgo#736813, bgo#736762.
  + Updated translations.
* Thu Aug 28 2014 zaitor@opensuse.org
- Update to version 1.4.1:
  + Bugs fixed: bgo#732851, bgo#733805, bgo#733974, bgo#734688,
    bgo#734773.
  + Updated translations.
* Mon Jul 21 2014 dimstar@opensuse.org
- Update to version 1.4.0:
  + Bugs fixed: bgo#733131, bgo#733121, bgo#733320.
  + Updated translations.
* Thu Jul 17 2014 dimstar@opensuse.org
- Update to version 1.3.91:
  + Various API additions.
  + New plugins and elements:
  - v4l2videodec element for accessing hardware codecs on
    platforms that make them accessible via V4L2.
  - New downloadbuffer element that replaces the download
    buffering feature of queue2.
  - rtpstreampay and rtpstreamdepay elements for transmitting RTP
    packets over a stream API (e.g. TCP) according to RFC 4571.
  - rtprtx elements for standard compliant implementation of
    retransmissions, integrated into the rtpmanager plugin.
  - audiomixer element that mixes multiple audio streams together
    into a single one while keeping synchronization.
  - OpenNI2 plugin for 3D cameras like the Kinect camera.
  - OpenEXR plugin for decoding high-dynamic-range EXR images.
  - curlsshsink and curlsftpsink to write files via SSH/SFTP.
  - videosignal, ivfparse and sndfile plugins ported from 0.10.
  - avfvideosrc, vtdec and other elements were ported from 0.10
    and are available on OS X and iOS now.
  + Other changes:
  - gst-libav now uses libav 10.1, and gained support for
    H265/HEVC.
  - Support for hardware codecs and special memory types has been
    improved with bugfixes and feature additions in various
    plugins and base classes.
  - Various bugfixes and improvements to buffering in queue2 and
    multiqueue elements.
  - dvbsrc supports more delivery mechanisms and other features
    now, including DVB S2 and T2 support.
  - The MPEGTS library has support for many more descriptors.
  - Major improvements to tsdemux and tsparse, especially time
    and seeking related.
  - souphttpsrc now has support for keep-alive connections,
    compression, configurable number of retries and configuration
    for SSL certificate validation.
  - hlsdemux has undergone major refactoring and works more
    reliable now and supports more HLS features like trick modes.
  - dashdemux and mssdemux are now also pushing fragments
    downstream while they're downloaded instead of waiting for
    each fragment to finish.
  - videoflip can automatically flip based on the orientation
    tag.
  - openjpeg supports the OpenJPEG2 API.
  - waylandsink was refactored and should be more useful now.
  - gst-rtsp-server supports SRTP and MIKEY now.
  - gst-libav encoders are now negotiating any profile/level
    settings with downstream via caps.
  - Lots of fixes for coverity warnings all over the place.
  - Negotiation related performance improvements.
  - 800+ fixed bug reports.
  + Things to look out for:
  - The eglglessink element was removed and replaced by the
    glimagesink element.
  - The mfcdec element was removed and replaced by v4l2videodec.
  - osxvideosink is only available in OS X 10.6 or newer.
  - On Android the namespace of the automatically generated Java
    class for initialization of GStreamer has changed from
    com.gstreamer to org.freedesktop.gstreamer to prevent
    namespace pollution.
  - On iOS you have to update your gst_ios_init.h and
    gst_ios_init.m in your projects from the one included in the
    binaries if you used the GnuTLS GIO module before.
* Fri Apr 25 2014 dimstar@opensuse.org
- Update to version 1.2.4:
  + bgo#724373: Queue2 truncates its temp file when pipeline is
    paused.
  + bgo#725517: docs: Fix typos and remove unknown annotations.
  + bgo#725809: ghostpad: rare crash because of missing reference
    count on its target pad.
  + bgo#727253: parse: Bison generated file included in the release
    tarballs causes compile errors.
  + bgo#727883: baseparse: Memory leak of queue frames.
* Sun Feb  9 2014 zaitor@opensuse.org
- Update to version 1.2.3:
  + Bugs fixed: bgo#712597, bgo#719814, bgo#721253, bgo#721289,
    bgo#721300, bgo#721350, bgo#721422, bgo#721941, bgo#722467.
  + Updated translations.
* Tue Dec 31 2013 zaitor@opensuse.org
- Update to version 1.2.2:
  + Bugs fixed: bgo#712597, bgo#719437, bgo#707230, bgo#712300,
    bgo#714989, bgo#719575.
* Mon Nov 11 2013 dimstar@opensuse.org
- Update to version 1.2.1:
  + core: Fix max DEBUG_LEVEL incongruence on 5 vs 9.
  + Bugs fixed: bgo#709804, bgo#709637.
  + Updated translations.
* Tue Oct 22 2013 dimstar@opensuse.org
- Update to version 1.2.0:
  + A bunch of API changes (new stable branch 1.2).
  + New tool: gst-play-1.0 in gst-plugins-base for basic playback
    testing on the command line.
  + New plugins:
  - mssdemux for Microsoft Smooth Streaming.
  - dashdemux for DASH adaptive streaming protocol.
  - bluez for interaction with Bluetooth devices.
  - openjpeg for JPEG2000 decoding and encoding.
  - daala for experimental Daala decoding and encoding.
  - vpx plugin has experimental VP9 decoding and encoding
    support.
  - webp plugin for WebP decoding (encoding to be added later).
  - Various others: yadif, srtp, sbc, fluidsynth, midiparse,
    mfc, ivtv, accuraterip and audiofxbad.
  + Moved plugins: dtmf, vp8rtp, scaletempo and rtpmux plugins are
    now in gstreamer-plugins-good.
  + Audio and Video related fixes.
  + Other changes:
  - gst-libav now uses libav 9.
  - Static linking of plugins is supported now.
  - rtspsrc: add support for NetClientClock.
  - RTP retransmission / NACK support and big RTP jitterbuffer
    improvements.
  - SRTP and DTLS support.
  - Changes to many elements and core to use the correct sticky
    event order and also not lose any important sticky events
    during flushing.
  - >1000 fixed bug reports, and many other bug fixes and other
    improvements everywhere that had no bug report.
  + Notes:
  - Single header includes for all libraries,
    e.g. #include <gst/video/video.h>
  - Stricter (correct) caps subset checking in some cases.
  - x264enc now outputs data in byte-stream by default if
    downstream has ANY caps.
  - The MPEG TS demuxer posts messages contain the PMT, PAT,
    etc, in a different format now.
  - The GstContext API has changed between 1.1.4 and 1.1.90.
* Sat Aug 31 2013 zaitor@opensuse.org
- Update to version 1.0.10:
  + parse: make gst-launch syntax parser work with Bison 3.
  + memory: only copy the requested part instead of the complete
    source memory for default system memory.
  + queue2: update buffering when changing capacity.
  + g-i:
  - Add bindings-friendly buffer.extract() function.
  - Miscellaneous gobject-introspection annotation fixes
    (queries, pipeline).
  + Bugs fixed: bgo#705630, bgo#705678, bgo#705751, bgo#706462.
* Thu Aug 15 2013 zaitor@opensuse.org
- Update to version 1.0.9:
  + basesink: when we asynchronously go from READY to PLAYING, also
    call the state change function so that subclasses can update
    their state for PLAYING, esp. audio sinks added to the pipeline
    dynamically.
  + bindings: gobject-introspection annotation fixes.
  + Bugs fixed: bgo#702282.
* Sat Jul 13 2013 dimstar@opensuse.org
- Update to version 1.0.8:
  + basesink: improve position reporting without clock.
  + Fix caps leak in typefind/decodebin/playbin.
  + Gobject-introspection fixes for bindings.
  + Bugs fixed: bgo#693365, bgo#702617, bgo#702778, bgo#703562.
* Sat Apr 27 2013 dimstar@opensuse.org
- Update to version 1.0.7:
  + Add better support for static plugins.
  + Bugs fixed: bgo#667305, bgo#696357, bgo#696435, bgo#697791.
* Sat Mar 23 2013 zaitor@opensuse.org
- Update to version 1.0.6:
  + bin: reset GValue from iterator after usage, fixing leak.
  + pipeline: fix seeking on pipeline with NULL clock.
  + message: accept NULL error argument in
    gst_message_parse_{error,warning,info}.
  + basesrc: handle renegotiation correctly.
  + basesink: handle sync of EOS after item without duration.
  + basetransform: avoid warnings from NULL outcaps passed to
    transform_size in shutdown race.
  + adapter, basesrc, typefind: handle gst_buffer_map failure.
  + queuearray:
  - fix gst_queue_array_drop_element().
  - fix gst_queue_array_find().
  + queue: remove query from queue if queue is flushing.
  + g-i:
  - make sure enumeration types and flags are introspected and
    available to bindings.
  - add allow-none annotation for gst_pipeline_new()'s name
    property.
  + Bugs fixed: bgo#684804, bgo#691185, bgo#691985, bgo#691986,
    bgo#692691, bgo#692868, bgo#693065, bgo#693587, bgo#693704,
    bgo#693996.
* Mon Feb 25 2013 sbrabec@suse.cz
- Added support for gnome-patch-traslation.
* Sat Jan 19 2013 dimstar@opensuse.org
- Update gstreamer-rpm-prov.patch: PackageKit is looking for
  packages with gstreamer(*) provides.. so we should provide the
  same.
* Wed Jan  9 2013 dimstar@opensuse.org
- Update to version 1.0.5:
  + Add GST_BIN_FLAG_NO_RESYNC flag that disables a resync when an
    element is added, removed or linked in the bin.
  + Add OTHER clock type
  + Bugs fixed: bgo#690915.
* Wed Dec 19 2012 dimstar@opensuse.org
- Update to version 1.0.4:
  + basesrc: fix potential leaks when re-activating in a different
    mode
  + bindings:
  - make all pad probe types work with bindings
  - fix gst_event_parse_stream_start() annotation, fixing crash
  + Documentation improvements.
  + Bugs fixed: bgo#687845, bgo#688804, bgo#688934.
* Thu Nov 22 2012 dimstar@opensuse.org
- Update to version 1.0.3:
  + bufferpool: fix deadlock.
  + baseparse: forward stream-start event in push mode, fixing
    issues with streamsynchronizer
  + basesink: reset START_TIME when needed, fixing position
    reporting after seeking beyond end
  + Bugs fixed: bgo#666053, bgo#687896, bgo#688477, bgo#688511,
    bgo#688655, bgo#685870.
* Thu Oct 25 2012 dimstar@opensuse.org
- Update to version 1.0.2:
  + Parallel installability with 0.10.x series
  + collectpads: ensure all timestamps are in same time domain
  + gobject-introspection: fix GstSample annotations
  + add GstElement::post_message() vfunc
  + info: allow gst_debug_add_log_function() to be called before
    gst_init()
  + event: allow GST_CLOCK_TIME_NONE as duration for GAP events
  + documentation: new chapters and updates for the application
    development manual and the plugin writer's guide
  + Bugs fixed: bgo#686456, bgo#686658, bgo#686659, bgo#686723,
    bgo#686787.
* Tue Oct  9 2012 dimstar@opensuse.org
- Update to version 1.0.1:
  + Capsfilter prefers filter caps over passthrough now
  + Application Development Manual, Plugin Writer's Guide and other
    documentation updated and extended for 1.0
  + Bugs fixed: bgo#680862, bgo#684538, bgo#684755, bgo#684765,
    bgo#684809, bgo#684970, bgo#684981, bgo#685072.
* Mon Sep 24 2012 dimstar@opensuse.org
- Update to version 1.0.0:
  + Minor bugfixes
  + Updated documentation.
* Tue Sep 18 2012 dimstar@opensuse.org
- Update to version 0.11.99:
  + Minor fixes
  + Remove GST_USE_UNSTABLE_API guard and defines.
* Fri Sep 14 2012 vuntz@opensuse.org
- Revert change from Sept 2nd: we'll actually rename things in
  gstreamer-0_10 instead, since that's the package which is
  versioned.
- Update gstreamer-rpm-prov.patch: we need to output gstreamer1.0()
  instead of gstreamer0.10() for the Provides.
- Version the gstreamer-utils Requires in devel subpackage, to
  avoid having a choice between the 0.10 package and this one.
* Fri Sep 14 2012 dimstar@opensuse.org
- Update to version 0.11.94:
  + gstcompat: fix backwards compat macro for
    gst_message_new_duration
  + baseparse:
  - Add a mode/flag for disabling PTS interpolation
  - Handle GAP and still-frame events
  - Restructure event handling
  - Store incoming cached events in reverse order
  - First attempt at handling both DTS and PTS
  + taglist:
  - add warning when we get something else than a sample for a
    sample tag
  + elementfactory:
  - don't crash if no element klass has been set(bgo#683865)
  + Updated documentations
  + Bugs fixed: bgo#581525, bgo#599546, bgo#608841, bgo#634927,
    bgo#645467, bgo#647759, bgo#657202, bgo#657640, bgo#657725,
    bgo#667293, bgo#672637, bgo#673319, bgo#673641, bgo#676935,
    bgo#677620, bgo#677621, bgo#677757, bgo#677818, bgo#677819,
    bgo#677898, bgo#677925, bgo#678017, bgo#678031, bgo#678181,
    bgo#678301, bgo#678742, bgo#678928, bgo#679080, bgo#679112,
    bgo#679145, bgo#679286, bgo#679378, bgo#679407, bgo#679506,
    bgo#679534, bgo#679535, bgo#680181, bgo#680306, bgo#680479,
    bgo#680495, bgo#680755, bgo#680796, bgo#680804, bgo#680805,
    bgo#681139, bgo#681153, bgo#681198, bgo#681322, bgo#681450,
    bgo#681575, bgo#681681, bgo#682958, bgo#682968, bgo#682997,
    bgo#683470, bgo#683865.
- Rebase gstreamer-rpm-prov.patch.
* Sun Sep  2 2012 dimstar@opensuse.org
- Make gstreamer 1.0 and 0.10 -devel parallel installable:
  + Rename gstreamer.attr to gstreamer1.attr
  + Rename gstreamer-provides to gstreamer-provides1
* Wed Aug  8 2012 dimstar@opensuse.org
- Update to version 0.11.93:
  + added scope to taglists and TOCs (stream or global)
  + countless gobject-introspection annotation fixes
  + GstMiniObject: add qdata() (for object-private data)
  + basesink now prerolls on GAP event
  + versioned variants of environment variables
  + major low-level GstMemory reworking
  + allow mini objects to be LOCKABLE for
    read/write/exclusive access, use this
    in GstMemory
  + add segment-done event in addition to segment-done message
  + make allocation query more extendable
  + send STREAM_START events and STREAM_START message
  + remove gst_tag_list_get_buffer(), add gst_tag_list_get_sample()
    and move tags of GST_TYPE_BUFFER to GST_TYPE_SAMPLE, esp.
    GST_TAG_IMAGE and GST_TAG_PREVIEW_IMAGE, also
    GST_TAG_ATTACHMENT and GST_TAG_APPLICATION_DATA
  + GstDateTime: add support for partial date times where not
    all fields are set
  + move DATE tag from GDate to GstDateTime (for partial dates)
  + major TOC API reworking, make TOC events sticky
  + audio/video base class fixes and some minor API changes
    (e.g. frame refcounting; negotiation; propose_allocation)
  + port GstVideoOverlayComposition to 0.11, add GstMeta for it
  + fixes everywhere, esp. playback-related (demuxers, decoders,
    parsers)
* Tue Jul 17 2012 dimstar@opensuse.org
- Update to version 0.11.92:
  + Parallel installability with 0.10.x series.
  + API cleanup and minor API improvements.
  + GstTagList is a refcounted type now.
  + Lots of bugfixes, cleanup and other improvements.
- Rebase gstreamer-rpm-prov.patch.
- Update gstreamer.prov to actually call gst-inspect-1.0.
* Mon May 14 2012 vuntz@opensuse.org
- Update to version 0.11.91:
  + API cleanup and minor improvements
  + More hiding of structs that don't need to be public
  + Addition of SNAP flag for seek events
* Fri Apr 20 2012 vuntz@opensuse.org
- Update to version 0.11.90:
  + Lots of bugfixes, cleanup and other improvements
  + Improvements to the buffer and memory managment API
  + A new GstTOC interface, e.g. for handling chapters
  + The GstChildProxy interface works with any GObject now
- Rebase gstreamer-no-gtk-doc-for-reals.patch.
- Rename libgstreamer-0_11-0 to libgstreamer-1_0-0 following
  upstream soname change.
- Rename typelib-1_0-Gst-0_11 to typelib-1_0-Gst-1_0 following
  upstream typelib name change.
* Fri Mar 23 2012 vuntz@opensuse.org
- Update to version 0.11.3:
  + Various bug fixes and improvements
  + Input-selector defaults to sync-streams=true
  + Queue don't just start the thread on linking
  + Add user_data and notify to gst_memory_new_wrapped()
  + Rework caps function for performance
  + Improve basetransform allocator handling
  + Implement metadata transforms
  + Metadata registration improvements
  + Use generic marshallers everywhere
  + Push Sticky events in more cases
  + Register queries like events
  + Add DRAIN serialized query
  + Add 0-padding and prefix to GstMemory
  + Rework the ALLOCATION query
  + Allow setting the allocator in a bufferpool
  + Improve pull/get_range
* Fri Feb 17 2012 dimstar@opensuse.org
- Update to version 0.11.2:
  + Added pts/dts to buffers
  + Moved controller into core
  + Pad probe rewrite
  + AcceptCaps and GetCaps made as queries
  + Added parent to pad functions
  + Sticky events rewrite
  + New GstSample object
  + Asynchronous state change support for basesrc
  + Added new bitmask type
  + GstMemory updates
  + Port to gio
  + Port to newest glib
  + Add stepped ranges
  + Do typefind in separate thread
  + Rework alloc tracing
  + Added STREAM_CONFIG, GAP and STREAM_START events
  + Various cleanups and leak fixes
- Rebase gstreamer-rpm-prov.patch.
* Tue Jan 24 2012 vuntz@opensuse.org
- Update to version 0.11.1:
  + Remove negotiation from state change in GstBaseSrc
  + Removed our custom FOURCC type
  + Updates to the base classes
* Sat Jan 21 2012 zaitor@opensuse.org
- Add libtool as explicit buildrequire to avoid implicit dependency
  from prjconf.
- Split typelib files into typelib-1_0-Gst-0_11 subpackage.
- Add typelib-1_0-Gst-0_11 Requires to devel subpackage.
- Add explicit libgstreamer-0_11-0 Requires to devel subpackage: it
  was there implicitly before, through the gstreamer
  Requires, but it's better to have it explicit.
- Add gstreamer-utils Requires to devel subpackage: it is needed
  for automatic provides rpm magic.
- Remove explicit check-devel, glib2-devel, libxml2-devel and
  popt-devel Requires from devel subpackage: the ones that are
  needed will be added the pkgconfig() way, and the others are
  actually wrong.
* Wed Aug  3 2011 dimstar@opensuse.org
- Update to version 0.11.0:
  + Reworked buffer memory management
  + Arbitrary buffer metadata
  + Integrated bufferpool management
  + Improved dynamic pipeline changes
  + Reworked video caps system
  + Reworked pad probes
- Clean spec-file using spec-cleaner.
- Rename package to gstramer-0_11:
  + Remove the old gstreamer010 provides and obsoletes. They are
    no longer true.
  + Rename all subpackage accordingly
  + Adjust baselibs.conf
* Fri Jun 17 2011 dimstar@opensuse.org
- Update to version 0.10.35:
  + Work around GLib atomic ops API change
  + Some minor win32/mingw fixes
  + Don't use G_CONST_RETURN in public headers (bgo#652211)
* Thu May 19 2011 mls@suse.de
- move gstreamer deps generator definition from rpm into
  the gstreamer-0.10-devel package
* Wed May 18 2011 dimstar@opensuse.org
- Update to version 0.10.34:
  + Fix multiqueue thread-safety regression
  + Don't set artificial 0-timestamp on first packet for TIME-based
    live sources
  + Bugs fixed: bgo#649369, bgo#649878.
* Wed May 11 2011 dimstar@opensuse.org
- Update to version 0.10.33:
  + atomicqueue: add an atomic/lock-free queue structure based
  + bufferlist: improve _add*() performance
  + bus: in _add_watch() honour any per-thread default main context
    set via g_main_thread_push_thread_default()
  + caps: new gst_caps_intersect_full() to intersect in different
    modes
  + clock: add functions to re-init existing periodic GstClockIDs
  + event: add QoS type (overflow, underflow, throttle) for QoS
    events
  + ghostpad: The internally linked pad of the proxypad is the
    ghostpad
  + gstpoll: retry reading the control socket to release properly
    all wakeups
  + message: new progress message API for asynchronous operations
  + pad:
  - unlock before freeing the pad cache to avoid deadlock
  - better handling for when parent goes away during
    data/query/event flow
  + parse-launch: allow element names to begin with digits
  + pluginloader: call gst-plugin-scanner with the right arch on
    OSX, fixing hangs with firefox
  + registry: fixes elements (features) disappearing if a plugin or
    plugin file is renamed
  + structure:
  - Add "(date)" as a type abbreviation of GDate
  - Don't allow invalid GDates in all structures and don't allow
    NULL GDates in taglists
  + taglist: add a new "encoded-by" tag
  + uri: add gst_filename_to_uri() that takes relative filenames
  + utils: add gst_element_factory_can_{src|sink}_{any|all}_caps()
    to replace can_{sink,src}_caps()
  + baseparse: new GstBaseParse class for parsers
  + basesink:
  - improve rate, duration, and average duration calculation
  - use new QoS types and add add "throttle-time" property
  + basesrc:
  - Handle tag and custom downstream events the same
  - keep downstream caps order when fixating, to honour
    downstream preferences when negotiating
  - Return FALSE if we don't handle an event
  - Send synchronized custom downstream/both events downstream
    from the streaming thread
  + basetransform:
  - Be smarter with pad allocs
  - Check for pad alloc caps when suggestion is not fixed
  - Retain caps order when getting caps, to honour downstream
    preferences when negotiating
  + funnel: new N-to-1 pipe fitting element imported from farsight
  + fakesink:
  - print buffer flags
  - Fix escaping of URIs
  + file{sink,src}:
  - Check if non-URI characters are escaped, but only for the URI
    not the location property
  - fix URI creation regression for non-absolute locations
  + filesrc: Fix escaping of file uris
  + inputselector:
  - Hold the selector lock while reading properties of the active
    pad
  - Make sure that EOS is always sent downstream for the active
    pad
  - Return GST_FLOW_OK until the selected pad pushed something
    downstream
  - Stop waiting for a pad switch when the pad is flushing
  + multiqueue:
  - fix some potential corner-case deadlocks and some leaks
  - handle arbitrary sink + source pad naming
  + queue2: don't read beyond the end of file upstream in pull
    mode; leak fixes
  + plugins: make query and event functions more thread-safe,
    protect against parent-pad disappearing
  + gst-launch: add GstIndex support
  + Bugs fixed: bgo#642356, bgo#402141, bgo#518857, bgo#604094,
    bgo#615357, bgo#617045, bgo#639674, bgo#639962, bgo#640071,
    bgo#640437, bgo#640502, bgo#640622, bgo#640675, bgo#640850,
    bgo#641212, bgo#641928, bgo#642071, bgo#642130, bgo#642271,
    bgo#642373, bgo#642393, bgo#642504, bgo#642522, bgo#642869,
    bgo#643301, bgo#643455, bgo#644935, bgo#645022, bgo#645267,
    bgo#645595, bgo#645746, bgo#645877, bgo#645931, bgo#646118,
    bgo#646341, bgo#646531, bgo#646566, bgo#646569, bgo#646624,
    bgo#646811, bgo#646971, bgo#647005, bgo#647131, bgo#647293,
    bgo#647763, bgo#647844, bgo#647922, bgo#648199, bgo#648215,
    bgo#648220, bgo#648297, bgo#649195, bgo#635718, bgo#625396,
    bgo#640771, bgo#646972, bgo#640665.
- Rebase gstreamer-0_10-rpm-prov.patch.
* Tue May  3 2011 dimstar@opensuse.org
- Extend gstreamer-0_10-rpm-prov.patch: Also provide elements.
* Tue Jan 25 2011 wstephenson@novell.com
- Update to version 0.10.32
  + GLib requirement is now >= 2.22
  + New core elements:
  - valve (moved from -bad)
  - input-selector (N.B. without "select-all" property, use fsfunnel
    instead) (moved from -bad)
  - output-selector (with different negotiation behaviour by
    default, set pad-negotiation-mode=active for previous behaviour)
    (moved from -bad)
  + Performance improvements for many heavily-used code paths:
    GstPad, GstPoll, GstClock, GstTask, basesink, basesrc, queue2,
    multiqueue
  + gobject-introspection: add annotations for most core API
  + clock: make sync clock wait lockfree
  + fdsrc/fdsink: reenable on MSVC
  + registry: fix GStatBuf definition for win32 when building against
    older glib (fixes unnecessary rescanning of plugins at start-up)
  + element: add a more flexible way to get request pads from elements
  + multiqueue: return upon input when already eos
  + object: fix creation of default name
    (when creating more than 100000 elements)
  + pluginloader: fix hangs on OSX
  + poll:
  - fixes for (p)select backend (used e.g. on OSX)
  - refactor and make more lockfree; fixes for win32 and OSX
    (pselect backend)
  + registry: don't replace valid existing plugins by blacklisted ones
  + tags: don't produce duplicated entries when merging same value twice
  + basesink:
  - preroll fixes for async=false case
  - rework position reporting code
  + basetransform: handle downstream giving a buffer with new caps
    but invalid size
* Sun Jan 16 2011 aj@suse.de
- Remove buildrequire on pyxml and add python instead for doc
  package only, changelog of package with date 2008-03-21 contains:
  "Don't depend on PyXML and use only XML modules that are shipped
  with python."
* Tue Dec  7 2010 vuntz@opensuse.org
- Update to version 0.10.31:
  + bin:
  - add "message-forward" property to force forwarding of
    messages that would usually be filtered such as ASYNC_DONE or
    EOS
  - improve tracking of source elements for more efficient event
    dispatch
  + bufferlist: add function to add a list of buffers
  + clock: fix racy shutdown clock id leak
  + element:
  - add support for arbitrary element class / factory details
  - link_many should activate pads if needed
  + gst: add math-compat.h header
  + datetime: add GstDateTime API
  + elementfactory: add utility functions to filter features by
    type
  + plugin: load the gst-python plugin loader with
    G_MODULE_BIND_LAZY
  + query: add buffering ranges API to retrieve informations about
    the areas of the stream currently buffered
  + value: add int64 range type
  + info: write debugging output to file if GST_DEBUG_FILE
    environment variable is set
  + pad: use more efficient g_object_notify_by_pspec() for caps
    notifies if compiling against new-enough GLib
  + pipeline: If the currently used clock gets lost update it the
    next time when going from PAUSED to playing
  + plugin: add release datetime field to GstPluginDesc and set it
    if GST_PACKAGE_RELEASE_DATETIME is defined
  + utils: speed up pad linking utility functions by not trying
    pads that will never work
  + adapter:
  - add function to get a list of buffers; support 0-sized
    buffers
  - optimize gst_adapter_take() and gst_adapter_peek() a little
  + basesink: only answer the SEGMENT query in pull mode
  + basesrc: return values in stream time for the POSITION query
  + basetransform:
  - allow the subclass to add new fields to caps when getting new
    caps from downstream
  - avoid useless memcpy
  - upstream caps-renegotiation fixes
  + bitreader: add inlined and unchecked versions of the most
    important functions
  + bytewriter:
  - add inline and unchecked variants of all important functions
  - fix possible infinite loop caused by an overflow
  + queue:
  - add "silent" property to suppress signal emission (for better
    performance)
  - avoid unnecessary g_cond_signal() (for better performance)
  - push newsegment event when linking in PLAYING
  + queue2:
  - extend ring buffer to support RAM mode
  - in download mode, prevent range corruption due to race
  - don't send seeks beyond the end of the file upstream in pull
    mode (fixes apple trailers and youtube/html5 playback in
    webkit)
  + multiqueue: flush the data queue if downstream return
    WRONG_STATE too
  + gst-inspect: print GST_PARAM_MUTABLE_* property flags
  + See NEWS for API additions and deprecations.
  + Bugs fixed: bgo#396774, bgo#482147, bgo#579127, bgo#594504,
    bgo#600004, bgo#610366, bgo#611918, bgo#618919, bgo#619522,
    bgo#621299, bgo#621332, bgo#622740, bgo#623040, bgo#623121,
    bgo#623491, bgo#623541, bgo#623622, bgo#623806, bgo#623875,
    bgo#624203, bgo#625239, bgo#625295, bgo#625368, bgo#625862,
    bgo#626027, bgo#626181, bgo#626651, bgo#626784, bgo#627438,
    bgo#627826, bgo#627910, bgo#627959, bgo#628014, bgo#628174,
    bgo#628176, bgo#628408, bgo#629241, bgo#629410, bgo#629494,
    bgo#629553, bgo#629831, bgo#629946, bgo#630257, bgo#630436,
    bgo#630437, bgo#630439, bgo#631755, bgo#631853, bgo#632236,
    bgo#632433, bgo#632977, bgo#633147, bgo#633886, bgo#635031,
    bgo#635389, bgo#635869, bgo#633176.
- Drop gstreamer-0_10-make382.patch: fixed upstream.
* Sat Sep 18 2010 vuntz@opensuse.org
- Move gir files to devel subpackage.
* Wed Sep 15 2010 dimstar@opensuse.org
- Extend gstreamer-0_10.prov: we need a possibility to simply skip
  the automatic provides function. In this case, defining
  SKIP_GSTPROVIDES to non-zero will be recognized as an ignore flag
  for the package. All other requires/provides will not be
  affected.
* Sat Sep 11 2010 dimstar@opensuse.org
- Add gstreamer-0_10-make382.patch: Fix build with make 3.82.
  Generally, the -doc package is affected.
* Thu Sep  2 2010 dimstar@opensuse.org
- Add gstreamer-0_10-rpm-prov.patch: adds --rpm to gst-inspect,
  allowing rpm to create a list of provides, thanks to the
  gstreamer-0_10.prov script we install. Those provides can then be
  picked up by PackageKit. Patch taken from Fedora's gstreamer
  package.
- Add gstreamer-0_10.macros that contains a rpm macro, in case
  external provides scripts are used.
- Add gstreamer-utils Requires to the -devel package: this is used
  in gstreamer-0_10.prov for the rpm magic to work.
* Tue Aug 31 2010 aj@suse.de
- Recommend instead of require lang package since it's not mandatory.
* Tue Aug 31 2010 aj@suse.de
- Recommend instead of require lang package since it's not mandatory.
* Thu Jul 29 2010 dimstar@opensuse.org
- Update to version 0.10.30:
  + bgo#623586: gst/tagsetter check fails
  + bgo#463435: Skip #include < libxml/parser.h > in gstconfig.h.in
    when not needed
  + bgo#505770: gst_element_get_state() should unblock if element
    posts an error
  + bgo#615820: implement percentage position and duration queries
  + bgo#615941: [tags] Add GST_TAG_DEVICE_MANUFACTURER and
    GST_TAG_DEVICE_MODEL
  + bgo#616586: Use GObject's boxed type for GError
  + bgo#617223: [tags] Add tags for direction of capture and
    movement
  + bgo#617625: Commandline utility wrappers (gst-run) don't work
    on Windows
  + bgo#618644: gst_pad_get_caps() Return pad template if parent
    element is in GST_STATE_NULL
  + bgo#619508: [tag] Add image orientation tag
  + bgo#619815: GST_PLUGIN_LOADING_WHITELIST env var for unit tests
  + bgo#619828: [API] adapter: add masked_scan_uint32_peek
  + bgo#620460: info: add new TRACE log level and move refcounting
    there from LOG level
  + bgo#620490: [basesink] segment query unconditionally returns
    FALSE
  + bgo#621006: Deprecate unused gst_object_{get|set}_name_prefix()
  + bgo#621282: Display of short fourccs is in hex instead of text
  + bgo#621332: BaseTransform should disable proxy alloc if
    downstream changes caps
  + bgo#621334: GstBaseTransform should not require a
    transform_size function
  + bgo#621505: Disable memory poisoning by default for releases
  + bgo#621527: gstcaps: New gst_caps_steal_structure() method
  + bgo#621530: filesink ignores sync=true
  + bgo#621595: --quiet doesnt make gst-launch be completely quiet,
    also messages should not go to stdout
  + bgo#621773: Add introspection annotations
  + bgo#621867: gst-launch: rename new --no-play command line
    option
  + bgo#621896: [API][taglist] Add gst_tag_list_peek_string_index
  + bgo#622504: [GstPad] Provide more fine-grained linking methods
  + bgo#622546: distcheck fails in docs/plugins/
  + bgo#622685: [GstXml] Deprecate GstXml
  + bgo#622967: [queue2] Problems with progressive downloading
  + bgo#623301: gst_caps_normalize: doesn't normalize completely
  + bgo#623589: Fix races/refcounting bugs with slave clocks
  + bgo#624113: [tags] wrong behaviour in merge function for
    strings
  + bgo#622025: Can't build gstreamer due to Gst-0.10.gir: error:
    Can't resolve type 'PadIntLinkFunction' for field
    Gst.Pad.intlinkfunc
* Tue May  4 2010 dimstar@opensuse.org
- Update to version 0.10.29:
  + improve plugin loading robustness: do not ever unload a plugin
    after calling into it: should fix mystery crashers during
    registry loading when a plugin init function returns FALSE
    (e.g. when some supporting library fails to initialise or a
    wrapper plugin found no features to wrap and wrongly returned
    FALSE)
  + configurable memory alignment for GstBuffers
  + add QoS message to inform apps of lost data, dropped frames etc
  + basesink, basetransform: add support for new QoS message
  + basetransform: accept non-fixed caps suggestions
  + basesrc: fix gst_base_src_new_seamless_segment()
  + GstController fixes and optimisations
  + set thread name for pad tasks on Linux
  + pipeline, bin: fix refcount issue when removing elements during
    a state change
  + queue2: implement seeking in download mode
  + queue2: implement flushing in download buffering
  + queue2: improve buffer level measurement in download mode
  + fdsrc: allow specifying the size in bytes on the uri
  + build fixes: better checks for uint128_t, inline assembly on
    OSX, compilation if HAVE_REGISTER_PRINTF_SPECIFIER is
    undefined, gobject-introspection
  + two symbols were removed that had been exported but never been
    used or been declared in any header file:
    gst_element_default_error & gst_element_request_compatible_pad.
- Drop gstreamer-0_10-fix-introspection-build.patch: upstreamed.
- Rebase gstreamer-0_10-no-gtk-doc-for-reals.patch.
* Sat Mar 13 2010 dimstar@opensuse.org
- Update to version 0.10.28:
  + No material changes compared to 0.10.27, this release is mostly
    to keep the version in sync with gst-plugins-base
  + Parse "1/MAX" fraction strings .
* Mon Mar  8 2010 dimstar@opensuse.org
- Update to version 0.10.27:
  + bgo#610366: [gstcollectpads][doc] Add a reminder for 'data' doc
  + bgo#605189: gst_element_get_state has wrong introspection
  + bgo#607771: [API] Add gst_byte_writer_fill
  + bgo#608036: [typefind] deadlock when upstream puts caps on
    buffers on pull mode
  + bgo#608877: [typefind] Access to internal fields not threadsafe
  + bgo#609941: GStreamer-WARNING **: External plugin loader failed
  + bgo#610210: [PATCH] Fix compilation of fdsink and fdsrc with
    MSVC
  + bgo#610246: [optimization] Speed up _get_range()
  + bgo#610367: [memindex] might busy loop upon EXACT lookup
  + bgo#610444: [controller] Interpolation control source passes
    NULL pointers to GSequence API
  + bgo#611087: [basesink] emergency rendering of late buffers
    fails after resuming from PAUSE
  + bgo#611719: GST_DEBUG_OBJECT macros not fed with GObject* in
    gstpoll.c
  + API additions:
  - gst_byte_writer_fill()
* Fri Feb 12 2010 dimstar@opensuse.org
- Update to version 0.10.26:
  + Changes:
  - registry: do plugin scanning (on *nix) using an external
    helper binary
  - lots of performance improvements all over the place
  - add GstByteWriter, a simple generic byte writer
  - filesink: Use _wfopen on win32 to open files with non-ascii
    filenames correctly.
  - queue2: add option to remove the temp-file (enabled by
    default)
  - it is now allowed to use gst_caps_set_simple() on non-simple
    caps
  - queue2: move from gst-plugins-base into the coreelements
    plugin in core
  - multiqueue: add support for buffering mode where we post
    BUFFERING messages based on the level of the queues
  - typefind: speed up typefinding a lot by first trying the
    typefinder for the file's extension
  - buffer: remove private/internal subbuffer subclass and keep
    track of the parent buffer directly in the GstBuffer
    structure
  - collectpads: add ability to install clipping functions
  - new tags for TV/Radio shows/episodes, lyrics, composer
    sortname and grouping
  - miniobject: avoid race when recycling buffers
  - basesrc: fix race in PLAYING->PAUSED->PLAYING
  + Bugs fixed: bgo#476514, bgo#590941, bgo#595602, bgo#535069,
    bgo#560442, bgo#595511, bgo#595886, bgo#595964, bgo#596366,
    bgo#597407, bgo#597550, bgo#597690, bgo#598297, bgo#598526,
    bgo#598700, bgo#598895, bgo#598896, bgo#599147, bgo#599759,
    bgo#600313, bgo#600922, bgo#601587, bgo#601668, bgo#601669,
    bgo#602093, bgo#602275, bgo#602419, bgo#603059, bgo#603787,
    bgo#604091, bgo#604093, bgo#605251, bgo#605930, bgo#606435,
    bgo#607283, bgo#607317, bgo#607431, bgo#607481, bgo#607739,
    bgo#607842, bgo#608136, bgo#608398, bgo#608442, bgo#608726,
    bgo#609166, bgo#590669, bgo#601698, bgo#604565, bgo#596877
  + API additions, see NEWS.
* Wed Jan  6 2010 jengelh@medozas.de
- Package baselibs.conf
* Thu Dec  3 2009 vuntz@opensuse.org
- Compile introspection support:
  + Add gobject-introspection-devel BuildRequires.
  + Pass --enable-introspection to configure.
  + Add gstreamer-0_10-fix-introspection-build.patch to fix the
    build.
- Small cleanups.
* Mon Nov 16 2009 lmedinas@opensuse.org
- Update to version 0.10.25:
  + Changes:
  - Improve the byte-reader API
  - GObject introspection support
  - Improve clock accuracy on win32
  - Optimisations in capabilities checking
  - Optimisations and fixes in the basetransform base class
  - New 64-bit scaling utility function variants
  - Various bug-fixes and improvements
  + Bugs fixed: bgo#583999, bgo#566881, bgo#588472, bgo#589173,
    bgo#589314, bgo#589524, bgo#589849, bgo#589991, bgo#590045,
    bgo#590430, bgo#590841, bgo#590919, bgo#591045, bgo#591318,
    bgo#591441, bgo#592209, bgo#592314, bgo#593460, bgo#593719,
    bgo#594107, bgo#594225, bgo#594990, bgo#595130, bgo#595133,
    bgo#595209, bgo#368536
* Mon Oct 26 2009 sbrabec@suse.cz
- Added support for translation-update-upstream (FATE#301344).
* Wed Aug 12 2009 sbrabec@suse.cz
- Create empty /usr/share/gstreamer-0.10/presets for presets.
* Wed Aug  5 2009 vuntz@novell.com
- Update to version 0.10.24:
  + Changes:
  - Fully support nested structures in caps
  - Support frame-by-frame stepping in sinks
  - Add support for buffer-lists to pass around groups of buffers
  - Use TaskPools for managing worker threads
  - New stream-status API for finer thread control
  - Code optimisations
  - Many other bug-fixes and enhancements
  + Bugs fixed: bgo#580579, bgo#527488, bgo#570233, bgo#584389,
    bgo#534208, bgo#545787, bgo#554460, bgo#559643, bgo#560345,
    bgo#560442, bgo#572285, bgo#577926, bgo#578908, bgo#580177,
    bgo#580716, bgo#581198, bgo#581281, bgo#582010, bgo#582564,
    bgo#582588, bgo#582878, bgo#583187, bgo#583419, bgo#583456,
    bgo#583554, bgo#584835, bgo#584838, bgo#585039, bgo#585075,
    bgo#585137, bgo#585592, bgo#585733, bgo#585748, bgo#586566,
    bgo#586568, bgo#587973, bgo#587976, bgo#588744, bgo#588745,
    bgo#589127, bgo#590056, bgo#590622, bgo#579177, bgo#581321,
    bgo#584118, bgo#585433, bgo#585569, bgo#585834, bgo#585960,
    bgo#587052
  + API additions.
* Sun May 17 2009 vuntz@novell.com
- Update to version 0.10.23:
  + Support files > 4GB on Windows
  + Controller interpolation fixes
  + Add timer support to GstPoll and use it for clocking
  + Attempt to typefind contents from the file extension if all
    else fails
  + GStreamer revision control switched to Git
  + Many other bug fixes and improvements
  + Bugs fixed: bgo#579177, bgo#163577, bgo#574160, bgo#575598,
    bgo#575922, bgo#576842, bgo#555978, bgo#565607, bgo#566936,
    bgo#567692, bgo#567725, bgo#568289, bgo#568438, bgo#568481,
    bgo#568632, bgo#568678, bgo#570910, bgo#571227, bgo#571559,
    bgo#572480, bgo#573623, bgo#574024, bgo#574211, bgo#574213,
    bgo#574241, bgo#574484, bgo#574623, bgo#574805, bgo#575695,
    bgo#575814, bgo#576381, bgo#576563, bgo#576582, bgo#577887,
    bgo#577891, bgo#578114, bgo#578201, bgo#579127, bgo#580121,
    bgo#361155, bgo#517231, bgo#572591, bgo#573823, bgo#574163,
    bgo#575682, bgo#575988
  + API additions:
  - New FIXME and MEMDUMP debug levels
  - gst_tag_list_get_buffer() and gst_tag_list_get_buffer_index()
  - New tags: GST_TAG_SUBTITLE_CODEC, GST_TAG_HOMEPAGE
  - gst_util_array_binary_search()
  - gst_message_new_request_state(),
    gst_message_parse_request_state(), GST_MESSAGE_REQUEST_STATE
  - GstPoll::gst_poll_new_timer()
  - GstPoll::gst_poll_write_control()
  - GstPoll::gst_poll_read_control()
* Thu Apr 23 2009 sbrabec@suse.cz
- Don't call autogen in older products.
* Thu Feb  5 2009 vuntz@novell.com
- Update to version 0.10.22:
  + GstController improvements
  + Extensions to the latency setting behaviours
  + Ability for plugins to register dependencies to trigger
    re-scanning
  + Optimisations in some common operations on caps and values and
    elsewhere
  + Add sequence numbers to events so dependent events can be
    associated with
  + the event that caused them
  + New macros for reading and writing float values
  + Many improvements in the basesink base class
  + Support non-default main contexts for GstBus watches
  + Improvements in pull-mode scheduling of sinks
  + Fixes for alignment issues on sparc
  + Ghost pad fixes
  + New bit-reader assistance API
  + Many other bug fixes and improvements
  + Bugs fixed: bgo#567002, bgo#350477, bgo#510354, bgo#526044,
    bgo#539108, bgo#544003, bgo#544293, bgo#545714, bgo#548786,
    bgo#551676, bgo#552778, bgo#553554, bgo#553874, bgo#555196,
    bgo#555307, bgo#555631, bgo#556091, bgo#556900, bgo#557154,
    bgo#557300, bgo#557438, bgo#557649, bgo#559250, bgo#560301,
    bgo#560360, bgo#560399, bgo#560442, bgo#561501, bgo#562170,
    bgo#562949, bgo#564863, bgo#567225, bgo#566393
  + API added:
  - Add bit reader and byte reader classes.
  - gst_message_new_structure_change()
  - gst_message_parse_structure_change()
  - GST_BUFFER_FREE_FUNC()
  - Add GST_READ_UINT24_(LE|BE) and GST_WRITE_UINT24_(LE|BE).
  - GstBaseSrc::gst_base_src_set_blocksize()
  - GstBaseSrc::gst_base_src_get_blocksize()
  - GstBaseSink::gst_base_sink_set_blocksize()
  - GstBaseSink::gst_base_sink_get_blocksize()
  - GstBaseSink::blocksize
  - GstBaseSink::gst_base_sink_do_preroll()
  - Add gst_byte_reader_get_data and gst_byte_reader_peek_data
  - Move float endianness conversion macros from libgstfloatcast to core
  - gst_util_seqnum_next, gst_util_seqnum_compare
  - gst_event_get_seqnum, gst_event_set_seqnum
  - gst_message_get_seqnum, gst_message_set_seqnum
  - GstSeekFlags::GST_SEEK_FLAG_SKIP
  - gst_bin_recalculate_latency()
  - GstBin::do-latency
  - gst_tag_setter_reset_tags()
  - gst_query_new_uri, gst_query_set_uri, gst_query_parse_uri
  - add gst_plugin_add_dependency()
  - add gst_plugin_add_dependency_simple()
- Drop gstreamer-0_10-protect-caps-bnc439323.patch: fixed upstream.
* Thu Nov  6 2008 sbrabec@suse.cz
- Fixed valgrid BuildRequires.
* Fri Oct 31 2008 gburt@suse.de
- Add patch from upstream to fix bad GST_CAPS bug in 0.10.21
    + Fixes bnc#439323 and bgo#555631
* Tue Oct 21 2008 maw@suse.de
- Update to version 0.10.21:
  +  Basetransform rework
  + Basesink synchronisation extensions
  + New documentation
  + Bugs fixed: bgo#481169, bgo#520694, bgo#538201, bgo#544855,
    bgo#339795, bgo#348114, bgo#361718, bgo#533856, bgo#536978,
    bgo#537804, bgo#537812, bgo#538568, bgo#539772, bgo#542175,
    bgo#543444, bgo#543853, bgo#544174, bgo#544776, bgo#545352,
    bgo#545603, bgo#545605, bgo#545607, bgo#545853, bgo#546328,
    bgo#546822, bgo#547277, bgo#547728, bgo#548394, bgo#548652,
    bgo#549504, bgo#551952, bgo#551978, bgo#547835, bgo#538628,
    bgo#546883, and bgo#551509
  + API added:
  * Add GST_TAG_ATTACHMENT for generic file attachments to streams.
  * Add gst_base_sink_set_render_delay()
  * Add gst_base_sink_get_render_delay()
  * Add gst_check_setup_src_pad_by_name
  * Add gst_check_setup_sink_pad_by_name
  * Add gst_check_teardown_pad_by_name
  * Add GstBaseTransform::gst_base_transform_suggest()
  * GstBaseTransform::gst_base_transform_reconfigure()
  * GstPad::gst_pad_set_iterate_internal_links_function()
  * GstPad::GstPadIterIntLinkFunction
  * GstPad::gst_pad_iterate_internal_links()
  * GstPad::gst_pad_iterate_internal_links_default()
  + API deprecated:
  * gst_pad_get_internal_links()
  * gst_pad_set_internal_link_function()
  * gst_pad_get_internal_links_default()
- Add gstreamer-0_10-no-gtk-doc-for-reals.patch.
* Thu Sep  4 2008 mboman@novell.com
- Update to version 0.10.20:
  + Add the Presets interface
  + Use the binary registry by default
  + Deprecate gst_element_get_pad and don't use it anywhere any more.
  + Reverse playback fixes
  + API to get missing element messages from parse_launch parsing.
  + Fixes in latency calculations
  + BaseTransform negotiation fixes
  + New Buffering query and messages
  + Fix multiqueue deadlocks when changing limits
  + Remove pre-generated parser hacks and require newer flex/bison
  + Use GSlice in more places
  + Use static strings in property declarations everywhere to save memory
    allocations
  + Fix unaligned memory accesses with the binary registry and add CRC
    checks
  + Lots of other bug fixes
* Wed May 14 2008 cthiel@suse.de
- fix baselibs.conf
* Tue Apr 29 2008 cthiel@suse.de
- obsolete gstreamer010-<arch> via baselibs.conf
* Tue Apr 15 2008 sbrabec@suse.cz
- fix build
* Mon Apr 14 2008 sbrabec@suse.cz
- Updated to version 0.10.19:
  * Fix a regression in raw fd handling
  * Fixed: bgo#524041
- Fixed Obsoletes (bnc#357153).
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Wed Apr  2 2008 maw@suse.de
- Update to version 0.10.18:
  + New GstPoll abstraction simplifies operations on multiple
    file descriptors
  + Bugs fixed: bgo#516187, bgo#516395, bgo#520756, bgo#498222,
    bgo#499127, bgo#505417, bgo#509559, bgo#510194, bgo#511783,
    bgo#513964, bgo#515469, bgo#519584, bgo#519698, bgo#520152,
    bgo#520671, bgo#520808, bgo#520877, bgo#521740, and bgo#522741.
* Wed Mar 19 2008 maw@suse.de
- Require texlive-latex and texlive-latex-doc to build.
* Tue Feb  5 2008 maw@suse.de
- Update to version 0.10.17:
  + Fix compilation problems
  + Bugs fixed: bgo#512715.
* Tue Feb  5 2008 maw@suse.de
- Update to version 0.10.16:
  + Monotonic/Posix clock support
  + Dumping of dot-file graph descriptions for debugging
  + Cleanup of exported symbols
  + Many bug fixes and enhancements
- Build with -fno-strict-aliasing.
* Tue Jan 22 2008 sbrabec@suse.cz
- Updated to version 0.10.15:
  * Changes for asynchronous sink management
  * New ts-offset property on basesink for adjusting clock synchronisation
  * New GstController LFO feature
  * Fixes and improvements in latency measurement for live pipelines
  * Additional documentation and docs fixes
  * Faster typefinding
  * More tag types added
  * Improvements in various core elements and parent classes
  * New unit tests
  * Allow dumping pipelines as dot graphs
  * GstStructures now support nesting
  * URIHandler interface can now be implemented in bindings
  * Many other bug-fixes and improvements
  * API additions
- Split package according to shared library packaging policy
  (#223286).
* Mon Sep 17 2007 sbrabec@suse.cz
- Updated to version 0.10.14:
  * State change handling improvements
  * New improved GstController API
  * Multi-queue fixes and enhancements
  * Fewer dynamic library relocations
  * Various other fixes and improvements
  * Parallel installability with 0.8.x series
  * Threadsafe design and API
  * Add GstParamSpecFraction, so elements can have fraction
    properties without lots of painful string parsing.
  * Add fail_unless_equals_float() and assert_equals_float()
  * Add gst_type_register_static_full
  * Add gst_element_class_set_details_simple
  * Refactor GstController into the core controller which can take
    a GstControlSource for providing actual values for timestamps.
  * add GST_TAG_LICENSE_URI and GST_TAG_COPYRIGHT_URI
  * gst_element_factory_has_interface()
  * Many bugs fixed.
* Wed Aug 15 2007 coolo@suse.de
- do not require lang package in doc
* Tue Aug  7 2007 maw@suse.de
- Split off a -lang subpackage
- s#%%run_ldconfig#/sbin/ldconfig/ in %%post and %%postun.
* Fri Jul 20 2007 aj@suse.de
- Create separate spec file for doc package.
* Thu Jul 12 2007 dmueller@suse.de
- fix installed headers to be compileable with -pedantic
* Wed Jun 20 2007 sbrabec@suse.cz
- Updated to version 0.10.13:
  * Latency handling infrastructure for live playback scenarios
  * State change handling changes
  * GstController property handling improved
  * Various bug fixes and improvements
  * Parallel installability with 0.8.x series
  * Threadsafe design and API
  * Many bugs fixed
  * Many API additions
* Wed May 16 2007 sbrabec@suse.cz
- Build correctly in older products.
* Sun Apr 22 2007 aj@suse.de
- Cleanup BuildRequires.
* Thu Apr 19 2007 schwab@suse.de
- Fix quoting in autoconf macros.
* Fri Mar 30 2007 aj@suse.de
- Add bison to build requires.
* Tue Mar 27 2007 sbrabec@suse.cz
- Updated to version 0.10.12:
  * API additions
  * Add a warning for improper GLib threading
  * Add support for binary registry serialisation
  * Preliminary support for pull-mode scheduling of entire chains
  * Add support for HPPA
  * Collectpads fixes
  * Lots of bug fixes
- Require check-devel.
* Tue Feb 13 2007 sbrabec@suse.cz
- Do not build unusable static libraries (#238552#c17).
* Mon Dec 18 2006 sbrabec@suse.cz
- Prefix changed to /usr.
- Spec file cleanup.
* Tue Nov 28 2006 sbrabec@suse.cz
- Build correctly in older products.
* Tue Nov  7 2006 abockover@suse.de
- Updated to version 0.10.10:
  * Scores of bug fixes
  * Better non-linear editing
  * Removed GLib 2.6 compatibility
  * Performance improvements on CPUs that support branch hints
  * __gst_debug_min symbol is properly externed
  * Can compile against GStreamer headers in pedantic mode
* Mon Jul 17 2006 danw@suse.de
- Rewrite XXXes to tmp file name before calling mkstemp a second
  time. Fixes the "gst-inspect doesn't work the first time" build bug.
* Fri Jun 16 2006 sbrabec@suse.cz
- Updated to version 0.10.8:
  * Many bug fixes
  * More API additions
  * Fixes for the collectpads helper
  * Support for proper time recording on server-trickmode streams
    via the applied_rate parameter of the NewSegment event
  * QoS in BaseTransform
  * BaseTransform reworked
  * Bus reworked; signal API added
  * Registry cache updating is now done in a fork, so no plugins
    are left opened
  * New version of data protocol now serializes events
* Thu May 25 2006 sbrabec@suse.cz
- Fixed uninitialized variable (#176290).
* Fri Mar 10 2006 jpr@suse.de
-update to version 0.10.4
-Changes since 0.10.3:
  * Parallel installability with 0.8.x series
  * Threadsafe design and API
  * 33%% of library size removed by parse change
  * (Experimental) QoS features (use max-lateness on BaseSink subclasses to enable)
  Bugs fixed since 0.10.3:
  * 323542 : GStreamer 0.10 hangs at EOS for all songs
  * 320340 : triggering a gst_task_join from the streaming task can de...
  * 322628 : document thread-unsafety of gst_value_foo() + gst_value_r...
  * 324186 : Smarter (deterministic!) typefind decisions
  * 324398 : varargs/valist functions aren't bindable
  * 328873 : only one gst_bin_recalc_state allowed at a time
  * 330899 : CVS directory in make dist tarball
  * 330906 : API: add GST_QUERY_TYPE_NAME and GST_MESSAGE_TYPE_NAME
  * 330996 : basesrc emits EOS unconditionally when going to READY
  * 331255 : Shrinking gst_parse_launch bloat
  * 331898 : Basetranform is not reusable
  * 332045 : API: GstPipeline needs API to disable  flushing of its bu...
  * 332277 : [filesrc] seek does not correct read position in non-mmap...
  * 332611 : [basesrc] needs way to prevent expensive start/stop in ch...
  * 332723 : New API: gst_type_find_helper_for_buffer
  * 333042 : New API: gst_type_find_helper_get_range
  * 333266 : Registry file writing rewrite
  * 333272 : tests should set G_SLICE=always-malloc now
  * 333417 : GST_BOILERPLATE_WITH_INTERFACE can't be used in C++ code
  * 333669 : Add pad accessor defines for GstBaseTransform
  * 333779 : New API: add gst_uri_has_protocol
  * 324818 : gst_registry_get_default doesn't sink newly created registry
  * 330125 : _pad_send_event does not check flushing correctly
  * 330684 : Add ability to emit sync-message without messing with the...
* Thu Feb 23 2006 jpr@suse.de
- update version to 0.10.3
- Changes since 0.10.2:
  * Documentation updates
  * Bug fixes
  * Base class improvements
  * Extra utility API
  * More elements ported from 0.8
  * Fixes for win32 build.
* Tue Feb 14 2006 sbrabec@suse.cz
- Do not package never generated registry.xml in /var (#149984).
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Jan 18 2006 sbrabec@suse.cz
- Updated to version 0.10.2.
* Tue Jan  3 2006 sbrabec@suse.cz
- Removed unneeded build requirements.
* Tue Jan  3 2006 sbrabec@suse.cz
- Updated to version 0.10.1.
* Tue Dec 13 2005 sbrabec@suse.cz
- Branched gstreamer010 and updated to version 0.10.0.
* Mon Nov 14 2005 sbrabec@suse.cz
- Fixed %%postun error on uninstallation.
* Fri Nov  4 2005 sbrabec@suse.cz
- Call branch-dependent gst-register (#132197).
* Mon Sep  5 2005 sbrabec@suse.cz
- Updated to version 0.8.11.
* Wed Jun  1 2005 sbrabec@suse.cz
- Fixed devel requirements (#72282).
* Thu May 26 2005 sbrabec@suse.cz
- Updated to version 0.8.10.
- Build all documentation.
- Split doc subpackage.
* Wed Mar 16 2005 sbrabec@suse.cz
- Build as user, copying xml.dcl is no more needed.
* Fri Feb 11 2005 gekker@suse.de
- Update to version 0.8.9
* Sat Jan 22 2005 ro@suse.de
- make docu build
* Mon Jan  3 2005 gekker@suse.de
- Update to version 0.8.8
* Tue Dec 21 2004 gekker@suse.de
- Update to version 0.8.7
* Mon Oct 11 2004 sbrabec@suse.cz
- Call gst-register properly (#46870).
* Tue Jun 22 2004 clahey@suse.de
- Fixed gst-register call to be in the right prefix.
* Fri Jun 11 2004 clahey@suse.de
- Don't use --gst-mask argument to gst-register.
* Wed Apr 28 2004 sbrabec@suse.cz
- Updated to version 0.8.1 (GNOME 2.6).
* Sun Mar 28 2004 ro@suse.de
- remove ghostscript-fonts-std from neededforbuild
  use plain ghostscript-mini to build
* Mon Mar 15 2004 sbrabec@suse.cz
- FHS 2.3 fix (mandir, infodir, #35821).
* Fri Feb 13 2004 sbrabec@suse.cz
- Updated to version 0.6.5.
- Build and install docs.
* Sat Jan 10 2004 adrian@suse.de
- use %%run_ldconfig
* Tue Nov  4 2003 ro@suse.de
- build with "-D_GNU_SOURCE" (for posix_memalign)
* Wed Oct 22 2003 sbrabec@suse.cz
- Updated to version 0.6.4.
* Thu Oct 16 2003 schwab@suse.de
- Add atomic ops for ia64.
- Fix warning.
* Wed Oct  8 2003 sbrabec@suse.cz
- Updated to version 0.6.3.
* Thu Sep 18 2003 sbrabec@suse.cz
- Call ldconfig before gst-register in %%post (bug #30675).
* Tue Sep 16 2003 sbrabec@suse.cz
- Call gst-register after installation.
- Added /var items to filelist.
* Mon Jul 14 2003 sbrabec@suse.cz
- GNOME prefix change to /opt/gnome.
* Fri Jun 27 2003 sbrabec@suse.cz
- Updated to version 0.6.2.
- Fixed %%files.
- Fixed directory packaging.
* Tue May 27 2003 ro@suse.de
- remove unpackaged files from buildroot
* Wed Feb  5 2003 meissner@suse.de
- ppc64 is basically ppc, the assembler stub needed is the same.
* Tue Feb  4 2003 sbrabec@suse.cz
- Updated to version 0.6.0.
* Thu Jan 23 2003 sbrabec@suse.cz
- Updated to version 0.5.2.
- FHS fix (localstatedir).
* Fri Jan 17 2003 sbrabec@suse.cz
- Updated to version 0.5.1 (Gnome2).
* Wed Nov 20 2002 ro@suse.de
- fix duplicates in configure.in
* Mon Nov 11 2002 ro@suse.de
- changed neededforbuild <jade_dsl> to <openjade>
* Fri Sep  6 2002 olh@suse.de
- fix build without atomic.h
* Thu Aug 22 2002 hhetter@suse.de
- added a README file and removed the SuSEconfig-script
  ( Bug Id#17620)
* Tue Aug 20 2002 hhetter@suse.de
- use Requires: %%{name} = %%{version} in devel package
- added PreReq: filesystem
* Thu Aug 15 2002 ro@suse.de
- removed gnome-utils from neededforbuild
* Sat Jul 27 2002 adrian@suse.de
- add %%run_ldconfig
* Fri Jul 26 2002 adrian@suse.de
- fix neededforbuld
* Thu Jul  4 2002 ro@suse.de
- neededforbuild quicktime4linux -> libquicktime
* Tue May 21 2002 meissner@suse.de
- %%_lib fixes, various libtool/autoconf/etc. patches.
- started port to x86_64
* Thu Jan 31 2002 ro@suse.de
- changed neededforbuild <libpng> to <libpng-devel-packages>
* Tue Jan 22 2002 ro@suse.de
- changed neededforbuild <kdelibs-artsd> to <kdelibs3-artsd>
* Fri Nov 30 2001 ro@suse.de
- changed neededforbuild <docbktls> to <docbook-toys>
* Wed Nov 28 2001 ro@suse.de
- removed libmpeg2 from neededforbuild
* Mon Nov 19 2001 ro@suse.de
- added new gnome-vfs include path to CFLAGS
- added popt, gconf and oaf to neededforbuild
* Sat Sep  8 2001 egger@suse.de
- Removed LAME due to legal reasons.
* Mon Aug 20 2001 ro@suse.de
- added diffs from cvs to build with current lame and current alsa
* Mon Aug 20 2001 ro@suse.de
- up to 0.2.1 to try to fix compilation
- added kdelibs-artsd to neededforbuild
* Wed Aug  8 2001 ro@suse.de
- changed neededforbuild <sdl> to <SDL>
- changed neededforbuild <sdl-devel> to <SDL-devel>
* Fri Jul 20 2001 kukuk@suse.de
- changed neededforbuild <gs_lib> to <ghostscript-library>
* Wed Jun 27 2001 hhetter@suse.de
- improved documentation support, enabled gtkdoc & docbkutils
* Tue Jun 26 2001 hhetter@suse.de
- added SuSEconfig.gstreamer script
- enabled sdl, libvorbis, ogg, gnome, alsa,
  cdparanoia, aalib and mpeg2 modules
- functionality test in chrooted environment
* Mon Jun 18 2001 hhetter@suse.de
- fixed typo in specfile
* Fri Jun 15 2001 hhetter@suse.de
- update to 0.2.0
- specfile & filelist rework
* Thu Mar 15 2001 hhetter@suse.de
- initial SuSE Package
